aboutsummaryrefslogtreecommitdiffhomepage
path: root/debugger
diff options
context:
space:
mode:
authorGravatar robertphillips <robertphillips@google.com>2014-07-01 08:47:04 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2014-07-01 08:47:04 -0700
commitdb539905bb3af7bd05839a7d2558e97d5cb51ca2 (patch)
tree00e3749598f44533d5980945baeb448608821f86 /debugger
parentbb6a02823929584231c8e080ee69e7fb1178cbfb (diff)
Rename SkPicturePlayback to SkPictureData
This is in preparation for splitting the playback portion of the new SkPictureData class into a new SkPicturePlayback class. R=reed@google.com, mtklein@google.com Author: robertphillips@google.com Review URL: https://codereview.chromium.org/362773002
Diffstat (limited to 'debugger')
-rw-r--r--debugger/QT/SkDebuggerGUI.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/debugger/QT/SkDebuggerGUI.cpp b/debugger/QT/SkDebuggerGUI.cpp
index a3783e9359..8610ebec5f 100644
--- a/debugger/QT/SkDebuggerGUI.cpp
+++ b/debugger/QT/SkDebuggerGUI.cpp
@@ -12,7 +12,7 @@
#include <QListWidgetItem>
#include "PictureRenderer.h"
#include "SkPictureRecord.h"
-#include "SkPicturePlayback.h"
+#include "SkPictureData.h"
__SK_FORCE_IMAGE_DECODER_LINKING;
@@ -155,15 +155,15 @@ void SkDebuggerGUI::showDeletes() {
}
}
// The timed picture playback uses the SkPicturePlayback's profiling stubs
// to time individual commands. The offsets are needed to map SkPicture
// offsets to individual commands.
-class SkTimedPicturePlayback : public SkPicturePlayback {
+class SkTimedPicturePlayback : public SkPictureData {
public:
static SkTimedPicturePlayback* CreateFromStream(SkStream* stream, const SkPictInfo& info,
SkPicture::InstallPixelRefProc proc,
const SkTDArray<bool>& deletedCommands) {
- // Mimics SkPicturePlayback::CreateFromStream
+ // Mimics SkPictureData::CreateFromStream
SkAutoTDelete<SkTimedPicturePlayback> playback(SkNEW_ARGS(SkTimedPicturePlayback,
(deletedCommands, info)));
if (!playback->parseStream(stream, proc)) {
@@ -256,7 +256,7 @@ protected:
#endif
private:
- typedef SkPicturePlayback INHERITED;
+ typedef SkPictureData INHERITED;
};
// Wrap SkPicture to allow installation of an SkTimedPicturePlayback object
@@ -286,19 +286,19 @@ public:
return NULL;
}
- void resetTimes() { ((SkTimedPicturePlayback*) fPlayback.get())->resetTimes(); }
+ void resetTimes() { ((SkTimedPicturePlayback*) fData.get())->resetTimes(); }
- int count() const { return ((SkTimedPicturePlayback*) fPlayback.get())->count(); }
+ int count() const { return ((SkTimedPicturePlayback*) fData.get())->count(); }
// return the fraction of the total time this command consumed
- double time(int index) const { return ((SkTimedPicturePlayback*) fPlayback.get())->time(index); }
+ double time(int index) const { return ((SkTimedPicturePlayback*) fData.get())->time(index); }
- const SkTDArray<double>* typeTimes() const { return ((SkTimedPicturePlayback*) fPlayback.get())->typeTimes(); }
+ const SkTDArray<double>* typeTimes() const { return ((SkTimedPicturePlayback*) fData.get())->typeTimes(); }
- double totTime() const { return ((SkTimedPicturePlayback*) fPlayback.get())->totTime(); }
+ double totTime() const { return ((SkTimedPicturePlayback*) fData.get())->totTime(); }
private:
// disallow default ctor b.c. we don't have a good way to setup the fPlayback ptr
SkTimedPicture();
// Private ctor only used by CreateTimedPicture, which has created the playback.
SkTimedPicture(SkTimedPicturePlayback* playback, int width, int height)
@@ -155,15 +155,15 @@ void SkDebuggerGUI::showDeletes() {
}
}
-// The timed picture playback uses the SkPicturePlayback's profiling stubs
+// The timed picture playback uses the SkPictureData's profiling stubs
// to time individual commands. The offsets are needed to map SkPicture
// offsets to individual commands.
@@ -286,19 +286,19 @@ public:
private:
- // disallow default ctor b.c. we don't have a good way to setup the fPlayback ptr
+ // disallow default ctor b.c. we don't have a good way to setup the fData ptr
SkTimedPicture();
// Private ctor only used by CreateTimedPicture, which has created the playback.